#
# spec file for package google-cloud-sdk
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           google-cloud-sdk
Version:        0.9.44
Release:        5.2
Summary:        Tools for Google Cloud Services
License:        Apache-2.0
Group:          System/Management
# Get the filename to download from
# https://dl.google.com/dl/cloudsdk/release/sha1.txt
Url:            https://dl.google.com/dl/cloudsdk/release
Source0:        %{name}-%{version}.tar.bz2
Source1:        setup.py
Patch1:         gsutilHideDeps.patch
Patch2:         gcutilHideDeps.patch
Patch3:         gcutilNoInternalVersionCheck.patch
Patch4:         bqHideDeps.patch
Patch5:         hideImplicitVersionMgmt.patch
Patch6:         hidePathMangeling.patch
Patch7:         gsutil_noVersioCheckOrUpdate.patch
Patch8:         gsutil_respectBotoCfgKeyword.patch
Requires:       google-api-python-client => 1.2
Requires:       python
Requires:       python-SocksiPy
Requires:       python-argcomplete
Requires:       python-argparse
Requires:       python-boto              => 2.30.0
Requires:       python-crcmod
Requires:       python-docker-py
Requires:       python-gcs-oauth2-boto-plugin
Requires:       python-google-apputils
Requires:       python-httplib2          => 0.8
Requires:       python-ipaddr
Requires:       python-iso8601
Requires:       python-python-gflags
Requires:       python-python-mimeparse
Requires:       python-requests
Requires:       python-retry_decorator
Requires:       python-setuptools
Requires:       python-six
Requires:       python-uritemplate
Requires:       python-websocket-client
Requires:       python-yaml
Provides:       gcutils > 1.13.0
Provides:       gsutils > 3.42
Obsoletes:      gcutils <= 1.13.0
Obsoletes:      gsutils <= 3.42
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Google Cloud SDK contains tools and libraries that allow you to create and
manage resources on Google Cloud Platform, including App Engine, Compute
Engine, Cloud Storage, Cloud SQL, and BigQuery.

%package doc
Summary:        Documentation for google-cloud-sdk
Group:          System/Management
PreReq:         google-cloud-sdk = %version

%description doc
This package provides html documentation for google-cloud-sdk

%package gsutil-tests
Summary:        Test for gsutil
Group:          System/Management
PreReq:         google-cloud-sdk = %version

%description gsutil-tests
This package provides test cases for gsutil. The functionality for gsutil
is not yet integrated into the gcloud master command utility.

%prep
%setup -q
%patch1
%patch2 -p1
%patch3 -p1
%patch4
%patch5
%patch6
%patch7
%patch8

cp %{SOURCE1} %{_builddir}/%{name}-%{version}

%build
python setup.py build
pushd platform/gsutil
python setup.py build
popd
pushd platform/gcutil
python setup.py build
popd
pushd platform/bq
python setup.py build
popd

%install
# Leave it to Google to set silly permissions, fix it
chmod -x help/man/man1/*
find . -name "*.html" | xargs chmod -x 
find . -name "*.json" | xargs chmod -x
find . -name "*_test.py" | xargs chmod +x
find lib/protorpc -name "*.py" | xargs chmod -x
# Remove shebang from files intended for import
sed -i 1d lib/protorpc/*.py 
sed -i 1d lib/protorpc/webapp/*.py 
sed -i 1d lib/protorpc/wsgi/*.py
# Install gcloud
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_defaultdocdir}/%{name}
install -d %{buildroot}/%{_mandir}
install -d %{buildroot}/%{_sysconfdir}/bash_completion.d
cp -r help/man/man1 %{buildroot}/%{_mandir}
cp completion.bash.inc %{buildroot}/%{_sysconfdir}/bash_completion.d/gcloud.sh
cp -r lib/googlecloudsdk/gcloud/reference/* %{buildroot}/%{_defaultdocdir}/%{name}
echo "#!/bin/sh" > %{buildroot}/%{_bindir}/gcloud
echo "python %{python_sitelib}/googlecloudsdk/gcloud/gcloud.py \"\$@\"" >> %{buildroot}/%{_bindir}/gcloud
chmod +x %{buildroot}/%{_bindir}/gcloud
# Install gsutil
pushd platform/gsutil
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
# install gcutil
pushd platform/gcutil
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
# Install bigquery
pushd platform/bq
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd

%files
%defattr(-,root,root,-)
# man pages for gcloud
%doc %{_mandir}/*
## gcloud stuff
%dir %{python_sitelib}/google
%dir %{python_sitelib}/googlecloudapis
%dir %{python_sitelib}/googlecloudsdk
%dir %{python_sitelib}/google_cloud_sdk-%{version}-py%{py_ver}.egg-info
%{_bindir}/gcloud
%{python_sitelib}/google/*
%{python_sitelib}/googlecloudapis/*
%{python_sitelib}/googlecloudsdk/*
%{python_sitelib}/google_cloud_sdk-%{version}-py%{py_ver}.egg-info/*
%config %{_sysconfdir}/bash_completion.d/gcloud.sh
# integrated gsutil
%dir %{python_sitelib}/gslib
%dir %{python_sitelib}/gslib/addlhelp
%dir %{python_sitelib}/gslib/commands
%dir %{python_sitelib}/gslib/data
# tests are accessed during regular command execution, go figure
%dir %{python_sitelib}/gslib/tests
# Note third_party contains protorpc which appears to be another
# implementation of the included dependency. Leave it to Google to
# mis-manage even in house developed dependencies.
%dir %{python_sitelib}/gslib/third_party
%dir %{python_sitelib}/gsutil-4.7-py%{py_ver}.egg-info
%doc %{python_sitelib}/gslib/CHECKSUM
%doc %{python_sitelib}/gslib/README
%doc %{python_sitelib}/gslib/VERSION
%{python_sitelib}/gslib/addlhelp/*
%{python_sitelib}/gslib/commands/*
%{python_sitelib}/gslib/data/*
%{python_sitelib}/gslib/tests/*
%{python_sitelib}/gsutil-4.7-py%{py_ver}.egg-info/*
%{python_sitelib}/gslib/third_party/*
%{python_sitelib}/gslib/*.py*
%{_bindir}/gsutil
# integrated gcutil
%dir %{python_sitelib}/gcutil_lib
%dir %{python_sitelib}/gcutil-1.16.5-py%{py_ver}.egg-info
%{python_sitelib}/gcutil_lib/*
%{python_sitelib}/gcutil-1.16.5-py%{py_ver}.egg-info/*
%{_bindir}/gcutil
# integrated bq
%dir %{python_sitelib}/discovery
%dir %{python_sitelib}/bigquery-2.0.18-py%{py_ver}.egg-info
%{python_sitelib}/discovery/*
%{python_sitelib}/bigquery_client.*
%{python_sitelib}/bq*
%{python_sitelib}/bigquery-2.0.18-py%{py_ver}.egg-info/*
%{python_sitelib}/table_formatter.*
%{_bindir}/bq
# built in dependency on protorpc, not available as stand alone code stream
%dir %{python_sitelib}/protorpc
%{python_sitelib}/protorpc/*

%files doc
%defattr(-,root,root)
%dir %{_defaultdocdir}/%{name}
%doc LICENSE README RELEASE_NOTES
%doc %{_defaultdocdir}/%{name}/*

%changelog
* Sat Jan 31 2015 rjschwei@suse.com
- Add patches:
    + gsutil_noVersioCheckOrUpdate.patch
    + gsutil_respectBotoCfgKeyword.patch
    + hidePathMangeling.patch
  Remove patches:
  - gcloudFixPath.patch
  - gsutilSupportBotoCfgKeyword.patch
- Update to version 0.9.44   bnc#915479
  + Fixes applied to the google/appengine-gobase image for managed VMs.
  + Tab completion for gcloud SQL commands.
  + Support added for authenticating service accounts with JSON keys.
    If using JSON keys, PyOpenSSL is no longer a dependency.
  + Suport for local ssds in instance templates for gcloud compute.
  + Progress Bars.
  + Compute Instances start/ stop commands.
  + Bug Fixes.
  + Added support for local SSD.
  + Added support for Google Compute Engine Instance Templates in
    compute component.
  + Overhaul of 'gcloud sql'
    ~ Updated the output for all commands.
    ~ Updated usage for 'gcloud sql ssl-certs create'.
  + Added support for creating and maintaining Cloud SQL read replica instances.
    ~ Added --master-instance-name property that can be set during replica
    creation to indicate the replication master for the read replica instance.
    ~ Added --enable-database-replication, --no-enable-database-replication
    flags that can be used to start, stop replication for the read replica
    instance.
    ~ Added 'promote-replica' command that promotes a read replica instance into
    a stand-alone Cloud SQL instance.
  + Added several new features to the compute component:
    ~ Implemented new subcommands for interacting with HTTP load balancing:
  - gcloud compute url-maps add-host-rule
  - gcloud compute url-maps add-path-matcher
  - gcloud compute url-maps remove-host-rule
  - gcloud compute url-maps remove-path-matcher
  - gcloud compute url-maps set-default-service
    ~ Added support for automatically generating initial Windows username and
    password when creating a virtual machine instance from a Windows
    image or a disk initializaed from a Windows image.
    ~ Added a new scope alias for Cloud SQL administration: 'sql-admin'.
  + The compute component is now in General Availability.
    ~ Added new 'compute/zone' and 'compute/region' properties that
    can be used to set a default zone and region. To set the
    properties, run 'gcloud config set compute/zone ZONE' and 'gcloud
    config set compute/region REGION'.
    ~ Added support for overriding disk auto-deletion during instance
    deletion.
    ~ Updated the output of commands that mutate resources to be more
    human-friendly. The --format flag can be used for more verbose
    output.
    ~ Replaced all 'get' subcommands with 'describe' subcommands (e.g.,
    'gcloud compute instances get' has been replaced with 'gcloud
    compute instances describe').
    ~ Renamed the 'firewalls' collection to 'firewall-rules'.
    ~ Added support to the 'addresses' collection for interacting with
    global addresses.
  + Updated gcutil to 1.16.3 and various AppEngine runtimes to 1.9.7 binaries.
  + Support running several modules by gcloud app run and fixed output errors.
  + Limit gcloud upgrade nags to once per day.
  + Bring help files up to date (for example improved the documentation
    for DM 'templates create' and 'deployments create').
  + Added prompting for regions and zones to most subcommands of the
    compute component.
  + Added new subcommands to the compute component for adding and removing
    backends from backend services.
  + Added --ssh-flags to 'gcloud compute ssh' for passing additional flags
    to ssh.
  + Added image alias support for the --image flag in the compute component.
  + Added --shell mode to all gcloud commands
    ~ Type a partial command followed by '--shell' to drop into a sub shell
    at that point in the command tree.
    ~ Eg:
    $ gcloud compute --shell
    gcloud compute $ instances list
    gcloud compute $ copy-files ...
  + Updated gsutil to 4.3
  + Allow installed crcmod to be used by default with gsutil by enabling
    site packages
* Fri Jun 27 2014 rschweikert@suse.com
- Disable the Google built in "component" management and version upgrade
  mechanism
  + add hideImplicitVersionMgmt.patch
* Sat Jun 21 2014 rschweikert@suse.com
- Fix setup file to properly include package data embedded in
  googlecloudsdk package, previously *.json files were missing
* Tue Jun 17 2014 rschweikert@suse.com
- Remove debug print from setup.py
- Include templated html files as data files, these are used by the
  auth setup workflow
* Fri Jun  6 2014 rschweikert@suse.com
- Remove unnecessary dependency on python-oauth2
* Thu Jun  5 2014 rschweikert@suse.com
- Update to version 0.9.25
  + 'gcloud preview app deploy' and '... run' argument updates.
  + 'gcloud config *' argument updates.
  + Updated all AppEngine tools to 1.9.5
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + gcloud now has App Engine and Cloud Datastore integration.
  - Commands can be found under `gcloud preview app` and
    `gcloud preview datastore`
  + New `gcloud compute` tool for working with compute engine (RC)
  - Run `gcloud components update compute` to install
  - Run `gcloud help compute` for more information
  + Updated all AppEngine tools to 1.9.4
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + Added color to error and warning messages (on Linux and Mac)
  - To disable, run `gcloud config set disable_color true`
  + New 'gcloud help command'
  - Displays man style extended help for commands (where available).
  + New 'gcloud auth activate-service-account' command
  - Used to authenticate with gcloud using a service account key file.
  - See: https://developers.google.com/storage/docs/authentication#service_accounts
- Enable "big query" install and use
  + add patch bqHideDeps.patch
- Fix use of gcloud command
  + add patch gcloudFixPath.patch
* Thu Mar  6 2014 rschweikert@suse.com
- Update to version 0.9.18
  + Updated all AppEngine tools to 1.9.0
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + New 'gcloud init' command
  - Creates a local workspace for your project with a git clone of
    your Google hosted repository.
  + Updated gcutil to 1.14.0
  - Switched to new, single API call for creating a virtual machine instance
    with a root persistent disk.
  - Added new command, 'setinstancediskautodelete', that sets the
    auto-delete option for persistent disks attached to virtual
    machine instances.
  - Added support for specifying a disk size when creating a disk using
    a snapshot.
  - Decreased the time spent waiting for SSH keys to propagate
    during initial instance creation from 120 seconds to 10 seconds.
* Thu Mar  6 2014 rschweikert@suse.com
- Disable gcutil internal version check
- add patch: gcutilNoInternalVersionCheck.patch
* Thu Mar  6 2014 rschweikert@suse.com
- Support the new boto config option and recognize the "system"
  keyword. Set the certificates file to None to use the system
  implementation
- add patch: gsutilSupportBotoCfgKeyword.patch
* Thu Feb 27 2014 rschweikert@suse.com
- Add missing dependency to python-setuptools
* Thu Feb 27 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
* Wed Feb 26 2014 rschweikert@suse.com
- Add missing package dependencies
* Wed Feb 26 2014 rschweikert@suse.com
- Remove the dependency on python-oauth2, this is only needed when using
  the oauth2client delivered with the sdk tarball. However, we use the
  already packaged version of the client google-api-python-client which
  does not have that dependency. Thus the dependency is superfluos.
* Mon Feb 24 2014 rschweikert@suse.com
- Fix the gcutilHideDeps.patch to hide requirements on python versions < 2.7
  this fixes build on SLE 11
* Mon Feb 24 2014 rschweikert@suse.com
- Use the setup.py code of the "integrated" gsutil and gcutil code
  the toplevel gsutil and gcutil commands are useless wrappers that play
  extremely stupid tricks with the path and other stuff.
- Add patch gsutilHideDeps.patch and gcutilHideDeps.patch to hide the
  hard dependencies for gsutil and gcutil, respectively
* Thu Feb 20 2014 rschweikert@suse.com
- Adjust version settings for obsoletes and provides
* Wed Feb 19 2014 rschweikert@suse.com
- Initial build
